summaryrefslogtreecommitdiffstats
path: root/net/proxy/proxy_service.h
diff options
context:
space:
mode:
Diffstat (limited to 'net/proxy/proxy_service.h')
-rw-r--r--net/proxy/proxy_service.h12
1 files changed, 8 insertions, 4 deletions
diff --git a/net/proxy/proxy_service.h b/net/proxy/proxy_service.h
index c596aab..8ea3653 100644
--- a/net/proxy/proxy_service.h
+++ b/net/proxy/proxy_service.h
@@ -47,12 +47,16 @@ class ProxyConfig {
std::string pac_url;
// If non-empty, indicates the proxy server to use (of the form host:port).
+ // If proxies depend on the scheme, a string of the format
+ // "scheme1=url[:port];scheme2=url[:port]" may be provided here.
std::string proxy_server;
- // If non-empty, indicates a comma-delimited list of hosts that should bypass
- // any proxy configuration. For these hosts, a direct connection should
- // always be used.
- std::string proxy_bypass;
+ // Indicates a list of hosts that should bypass any proxy configuration. For
+ // these hosts, a direct connection should always be used.
+ std::vector<std::string> proxy_bypass;
+
+ // Indicates whether local names (no dots) bypass proxies.
+ bool proxy_bypass_local_names;
// Returns true if the given config is equivalent to this config.
bool Equals(const ProxyConfig& other) const;